Denna modul är för att änkelt kunna få keno spel i python


Skapad av: "Xtarii : https://github.com/Xtarii/KenoPython"


-----------------------------------------------------------

Start with importing

then call on "GamblingGame().main()"